@@ -40,6 +40,7 @@
 #include <gconf/gconf-client.h>
 
 #include "config-gconf.h"
+#include "gconf-utils.h"
 #include "utils.h"
 #include "mapper-types.h"
 #include "latlon.h"
@@ -57,11 +58,6 @@
 
 #define PROXY_PORT (8080)
 
-gint mapper_gconf_get_int(const gchar *path, gint def);
-gint mapper_gconf_get_bound_int(const gchar *path, gint def, gint min, gint max);
-gfloat mapper_gconf_get_float(const gchar *path, gfloat def);
-gboolean mapper_gconf_get_boolean(const gchar *path, gboolean def);
-
 void 
 config_update_proxy(void)
 {
@@ -74,7 +70,7 @@ _http_proxy_port=0;
 /* Get proxy data and register for updates. */
 if (gconf_client_get_bool(gconf_client, GCONF_KEY_HTTP_PROXY_ON, NULL)) {
 	_http_proxy_host=gconf_client_get_string(gconf_client, GCONF_KEY_HTTP_PROXY_HOST, NULL);
-	_http_proxy_port=mapper_gconf_get_int(GCONF_KEY_HTTP_PROXY_PORT, PROXY_PORT);
+	_http_proxy_port=mapper_gconf_get_int(gconf_client, GCONF_KEY_HTTP_PROXY_PORT, PROXY_PORT);
 }
 }
 
@@ -401,40 +397,40 @@ g_mkdir_with_parents(config_dir, 0700);
 
 /* Get Receiver MAC from GConf.  Default is scanned via hci_inquiry. */
 _gps->io.address=gconf_client_get_string(gconf_client, GCONF_KEY_GPS_MAC, NULL);
-_gps->io.port=mapper_gconf_get_int(GCONF_KEY_GPS_PORT, 2947);
-_gps->io.type=(GpsIOSourceType)mapper_gconf_get_bound_int(GCONF_KEY_GPS_TYPE, GPS_IO_SIMULATION, GPS_IO_TYPE_MIN+1, GPS_IO_TYPE_MAX-1);
+_gps->io.port=mapper_gconf_get_int(gconf_client, GCONF_KEY_GPS_PORT, 2947);
+_gps->io.type=(GpsIOSourceType)mapper_gconf_get_bound_int(gconf_client, GCONF_KEY_GPS_TYPE, GPS_IO_SIMULATION, GPS_IO_TYPE_MIN+1, GPS_IO_TYPE_MAX-1);
 
 /* Get Auto-Download.  Default is FALSE. */
 _auto_download = gconf_client_get_bool(gconf_client, GCONF_KEY_AUTO_DOWNLOAD, NULL);
 
-_center_ratio=mapper_gconf_get_int(GCONF_KEY_CENTER_SENSITIVITY, 7);
-_lead_ratio=mapper_gconf_get_int(GCONF_KEY_LEAD_AMOUNT, 5);
-_draw_width=mapper_gconf_get_int(GCONF_KEY_DRAW_WIDTH, 4);
+_center_ratio=mapper_gconf_get_int(gconf_client, GCONF_KEY_CENTER_SENSITIVITY, 7);
+_lead_ratio=mapper_gconf_get_int(gconf_client, GCONF_KEY_LEAD_AMOUNT, 5);
+_draw_width=mapper_gconf_get_int(gconf_client, GCONF_KEY_DRAW_WIDTH, 4);
 
 /* Invalidate destination */
 _dest.valid=FALSE;
 
 /* Get Announce Advance Notice - Default is 30. */
-_announce_notice_ratio=mapper_gconf_get_int(GCONF_KEY_ANNOUNCE_NOTICE, 8);
+_announce_notice_ratio=mapper_gconf_get_int(gconf_client, GCONF_KEY_ANNOUNCE_NOTICE, 8);
 
-_announce_waypoints=mapper_gconf_get_boolean(GCONF_KEY_ANNOUNCE_WAYPOINTS, TRUE);
-_announce_overspeed=mapper_gconf_get_boolean(GCONF_KEY_ANNOUNCE_OVERSPEED, FALSE);
-_announce_destination=mapper_gconf_get_boolean(GCONF_KEY_ANNOUNCE_DESTINATION, FALSE);
+_announce_waypoints=mapper_gconf_get_boolean(gconf_client, GCONF_KEY_ANNOUNCE_WAYPOINTS, TRUE);
+_announce_overspeed=mapper_gconf_get_boolean(gconf_client, GCONF_KEY_ANNOUNCE_OVERSPEED, FALSE);
+_announce_destination=mapper_gconf_get_boolean(gconf_client, GCONF_KEY_ANNOUNCE_DESTINATION, FALSE);
 
 /* Get Enable Voice flag.  Default is TRUE. */
-_enable_voice=mapper_gconf_get_boolean(GCONF_KEY_ENABLE_VOICE, TRUE);
-_voice_pitch=mapper_gconf_get_bound_int(GCONF_KEY_VOICE_PITCH, 50, 10, 99);
-_voice_speed=mapper_gconf_get_bound_int(GCONF_KEY_VOICE_SPEED, 120, 80, 370);
+_enable_voice=mapper_gconf_get_boolean(gconf_client, GCONF_KEY_ENABLE_VOICE, TRUE);
+_voice_pitch=mapper_gconf_get_bound_int(gconf_client, GCONF_KEY_VOICE_PITCH, 50, 10, 99);
+_voice_speed=mapper_gconf_get_bound_int(gconf_client, GCONF_KEY_VOICE_SPEED, 120, 80, 370);
 
 /* Get Always Keep On flag.  Default is FALSE. */
-_always_keep_on=mapper_gconf_get_boolean(GCONF_KEY_ALWAYS_KEEP_ON, FALSE);
+_always_keep_on=mapper_gconf_get_boolean(gconf_client, GCONF_KEY_ALWAYS_KEEP_ON, FALSE);
 
-filter.enabled = gconf_client_get_bool(gconf_client, GCONF_KEY_GPS_FILTER, NULL);
-filter.hdop = gconf_client_get_float(gconf_client, GCONF_KEY_GPS_FILTER_HDOP, NULL);
-filter.vdop = gconf_client_get_float(gconf_client, GCONF_KEY_GPS_FILTER_VDOP, NULL);
-filter.angle = gconf_client_get_float(gconf_client, GCONF_KEY_GPS_FILTER_ANGLE, NULL);
-filter.osm = gconf_client_get_float(gconf_client, GCONF_KEY_GPS_FILTER_OSM, NULL);
-filter.maxdrop = gconf_client_get_int(gconf_client, GCONF_KEY_GPS_FILTER_MAXDROP, NULL);
+filter.enabled=gconf_client_get_bool(gconf_client, GCONF_KEY_GPS_FILTER, NULL);
+filter.hdop=gconf_client_get_float(gconf_client, GCONF_KEY_GPS_FILTER_HDOP, NULL);
+filter.vdop=gconf_client_get_float(gconf_client, GCONF_KEY_GPS_FILTER_VDOP, NULL);
+filter.angle=gconf_client_get_float(gconf_client, GCONF_KEY_GPS_FILTER_ANGLE, NULL);
+filter.osm=gconf_client_get_float(gconf_client, GCONF_KEY_GPS_FILTER_OSM, NULL);
+filter.maxdrop=gconf_client_get_int(gconf_client, GCONF_KEY_GPS_FILTER_MAXDROP, NULL);
 filter.drop_cnt=0;
 
 filter.maxdrop=CLAMP(filter.maxdrop, 0, 60);
@@ -444,7 +440,7 @@ filter.angle=CLAMP(filter.angle, 0, 45);
 
 /* Get Units.  Default is UNITS_KM. */
 {
-	gchar *units_str = gconf_client_get_string(gconf_client, GCONF_KEY_UNITS, NULL);
+	gchar *units_str=gconf_client_get_string(gconf_client, GCONF_KEY_UNITS, NULL);
 	guint i = 0;
 	if (units_str)
 		for (i = UNITS_ENUM_COUNT - 1; i > 0; i--)
@@ -500,7 +496,7 @@ _speed_limit = gconf_client_get_int(gconf_client, GCONF_KEY_SPEED_LIMIT, NULL);
 CLAMP(_speed_limit, 10, 300);
 
 /* Get Auto-Download.  Default is FALSE. */
-_auto_download=mapper_gconf_get_boolean(GCONF_KEY_AUTO_DOWNLOAD, FALSE);
+_auto_download=mapper_gconf_get_boolean(gconf_client, GCONF_KEY_AUTO_DOWNLOAD, FALSE);
 
 /* Get saved locations */
 config_load_position(&gps, GCONF_KEY_POSITION_GPS);
@@ -539,24 +535,24 @@ _route_dir_uri = gconf_client_get_string(gconf_client, GCONF_KEY_ROUTEDIR, NULL)
 /* Get Last Track File.  Default is NULL. */
 _track_file_uri = gconf_client_get_string(gconf_client, GCONF_KEY_TRACKFILE, NULL);
 
-_center_mode=mapper_gconf_get_int(GCONF_KEY_AUTOCENTER_MODE, CENTER_LEAD);
+_center_mode=mapper_gconf_get_int(gconf_client, GCONF_KEY_AUTOCENTER_MODE, CENTER_LEAD);
 
 /* Get Show Scale flag.  Default is TRUE. */
-_show_scale=mapper_gconf_get_boolean(GCONF_KEY_SHOWSCALE, TRUE);
+_show_scale=mapper_gconf_get_boolean(gconf_client, GCONF_KEY_SHOWSCALE, TRUE);
 
 /* Get Show Tracks flag.  Default is TRUE. */
-_show_tracks |= mapper_gconf_get_boolean(GCONF_KEY_SHOWTRACKS, TRUE) ? TRACKS_MASK : 0;
+_show_tracks |= mapper_gconf_get_boolean(gconf_client, GCONF_KEY_SHOWTRACKS, TRUE) ? TRACKS_MASK : 0;
 
 /* Get Show Routes flag.  Default is TRUE. */
-_show_tracks |= mapper_gconf_get_boolean(GCONF_KEY_SHOWROUTES, TRUE) ? ROUTES_MASK : 0;
+_show_tracks |= mapper_gconf_get_boolean(gconf_client, GCONF_KEY_SHOWROUTES, TRUE) ? ROUTES_MASK : 0;
 
 /* Get Show Velocity Vector flag.  Default is TRUE. */
-_show_velvec=mapper_gconf_get_boolean(GCONF_KEY_SHOWVELVEC, TRUE);
+_show_velvec=mapper_gconf_get_boolean(gconf_client, GCONF_KEY_SHOWVELVEC, TRUE);
 
-_show_poi=mapper_gconf_get_boolean(GCONF_KEY_SHOWPOIS, TRUE);
+_show_poi=mapper_gconf_get_boolean(gconf_client, GCONF_KEY_SHOWPOIS, TRUE);
 
 /* Get Enable GPS flag. Default is FALSE. */
-_enable_gps=mapper_gconf_get_boolean(GCONF_KEY_ENABLE_GPS, FALSE);
+_enable_gps=mapper_gconf_get_boolean(gconf_client, GCONF_KEY_ENABLE_GPS, FALSE);
 
 /* Initialize _conn_state based on _enable_gps-> */
 _gps->io.conn = (_enable_gps ? RCVR_DOWN : RCVR_OFF);
@@ -564,14 +560,14 @@ _gps->io.conn = (_enable_gps ? RCVR_DOWN : RCVR_OFF);
 config_load_string_list(GCONF_KEY_ROUTE_LOCATIONS, &_loc_list, &_loc_model);
 
 /* Show POIs below zoom */
-_poi_zoom = mapper_gconf_get_bound_int(GCONF_KEY_POI_ZOOM, 6, 0, 10);
+_poi_zoom = mapper_gconf_get_bound_int(gconf_client, GCONF_KEY_POI_ZOOM, 6, 0, 10);
 
 /* Set Route Download URL. */
 _route_dl_url=g_strdup(ROUTE_DOWNLOAD_URL);
 
 /* Get Route Download Radius.  Default is 4. */
-_route_dl_radius = mapper_gconf_get_int(GCONF_KEY_ROUTE_DL_RADIUS, 4);
-_track_dl_radius = mapper_gconf_get_int(GCONF_KEY_TRACK_DL_RADIUS, 4);
+_route_dl_radius=mapper_gconf_get_int(gconf_client, GCONF_KEY_ROUTE_DL_RADIUS, 4);
+_track_dl_radius=mapper_gconf_get_int(gconf_client, GCONF_KEY_TRACK_DL_RADIUS, 4);
 
 /* Get Colors. */
 for (i = 0; i < COLORABLE_ENUM_COUNT; i++) {
@@ -595,72 +591,4 @@ gconf_client_clear_cache(gconf_client);
 g_free(config_dir);
 }
 
-/**
- *
- */
-gint 
-mapper_gconf_get_int(const gchar *path, gint def)
-{
-GConfValue *value;
-gint v;
 
-g_assert(gconf_client);
-value=gconf_client_get(gconf_client, path, NULL);
-if (value) {
-	v=gconf_value_get_int(value);
-	gconf_value_free(value);
-} else {
-	v=def;
-}
-return v;
-}
-
-/**
- *
- */
-gboolean
-mapper_gconf_get_boolean(const gchar *path, gboolean def)
-{
-GConfValue *value;
-gboolean r;
-
-g_assert(gconf_client);
-value = gconf_client_get(gconf_client, path, NULL);
-if (value) {
-	r=gconf_value_get_bool(value);
-	gconf_value_free(value);
-} else {
-	r=def;
-}
-return r;
-}
-
-/**
- *
- */
-gint
-mapper_gconf_get_bound_int(const gchar *path, gint def, gint min, gint max)
-{
-gint r;
-
-r=mapper_gconf_get_int(path, def);
-CLAMP(r, min, max);
-return r;
-}
-
-gfloat
-mapper_gconf_get_float(const gchar *path, gfloat def)
-{
-GConfValue *value;
-gfloat v;
-
-g_assert(gconf_client);
-value=gconf_client_get(gconf_client, path, NULL);
-if (value) {
-	v=gconf_value_get_float(value);
-	gconf_value_free(value);
-} else {
-	v=def;
-}
-return v;
-}
