@@ -83,6 +83,10 @@ typedef enum {
 	INSIDE_PATH_POINT_DESC,
 	INSIDE_PATH_POINT_NAME,
 	INSIDE_PATH_WPT,
+
+	INSIDE_EXT,
+	INSIDE_EXT_TURN,
+
 	FINISH=5000,
 	UNKNOWN=6666,
 	ERROR=9999,
@@ -369,9 +373,21 @@ case INSIDE_PATH_POINT:
 		data->state = INSIDE_PATH_POINT_DESC;
 	else if (!strcmp((gchar *) name, "name"))
 		data->state = INSIDE_PATH_POINT_NAME;
+	else if (!strcmp((gchar *) name, "extensions"))
+		data->state = INSIDE_EXT;
 	else
 		MACRO_SET_UNKNOWN(name);
 break;
+case INSIDE_EXT:
+	g_debug("Ext");
+	if (!strcmp((gchar *) name, "turn"))
+		data->state=INSIDE_EXT_TURN;
+	else
+		MACRO_SET_UNKNOWN(name);
+break;
+case INSIDE_EXT_TURN:
+	g_debug("TurnS");
+break;
 case UNKNOWN:
 	data->unknown_depth++;
 	g_debug("SU: %d: %s", data->unknown_depth, name);
@@ -512,10 +528,37 @@ case INSIDE_PATH_POINT_DESC:
 		MACRO_SET_ERROR(name, "");
 break;
 case INSIDE_PATH_POINT_NAME:
-		/* Just ignore these for now */
-		g_string_free(data->chars, FALSE);
-		data->chars = g_string_new("");
-		data->state = INSIDE_PATH_POINT;
+	/* Just ignore these for now */
+	g_string_free(data->chars, FALSE);
+	data->chars = g_string_new("");
+	data->state = INSIDE_PATH_POINT;
+break;
+case INSIDE_EXT:
+	data->state=INSIDE_PATH_POINT;
+break;
+case INSIDE_EXT_TURN:
+	data->state=INSIDE_EXT;
+	g_debug("Turn: %s", data->chars->str);
+	if (strcmp(data->chars->str, "C")==0)
+		path->wtail->t=WPT_CONTINUE;
+	else if (strcmp(data->chars->str, "TL")==0)
+		path->wtail->t=WPT_TURN_LEFT;
+	else if (strcmp(data->chars->str, "TSLL")==0)
+		path->wtail->t=WPT_TURN_S_LEFT;
+	else if (strcmp(data->chars->str, "TSHL")==0)
+		path->wtail->t=WPT_TURN_H_LEFT;
+	else if (strcmp(data->chars->str, "TR")==0)
+		path->wtail->t=WPT_TURN_RIGHT;
+	else if (strcmp(data->chars->str, "TSLR")==0)
+		path->wtail->t=WPT_TURN_S_RIGHT;
+	else if (strcmp(data->chars->str, "TSHR")==0)
+		path->wtail->t=WPT_TURN_H_RIGHT;
+	else if (strcmp(data->chars->str, "TU")==0)
+		path->wtail->t=WPT_U_TURN;
+	else
+		path->wtail->t=WPT_POINT;
+	g_string_free(data->chars, FALSE);
+	data->chars=g_string_new("");
 break;
 case UNKNOWN:
 	g_debug("EU: %d: %s (%d)", data->unknown_depth, name, data->prev_state);
@@ -546,6 +589,7 @@ case INSIDE_PATH_POINT_ELE:
 case INSIDE_PATH_POINT_TIME:
 case INSIDE_PATH_POINT_DESC:
 case INSIDE_PATH_POINT_NAME:
+case INSIDE_EXT_TURN:
 	for (i = 0; i < len; i++)
 		data->chars = g_string_append_c(data->chars, ch[i]);
 	/* g_debug("GPXC: %s", data->chars->str); */
