@@ -1109,10 +1109,6 @@ if (!(event->state & GDK_BUTTON1_MASK)) {
 	return TRUE;
 }
 
-map_dragged++;
-if (map_dragged<16)
-	return FALSE;
-
 if (event->is_hint) {
 	gdk_window_get_pointer(event->window, &xx, &yy, &state);
 	state = event->state;
@@ -1122,6 +1118,13 @@ if (event->is_hint) {
 	state = event->state;
 }
 
+if (map_dragged==0 && calculate_idistance(xx, yy, before[0], before[1])>16) {
+	map_dragged++;
+	before[0]=xx;
+	before[1]=yy;
+} else if (map_dragged==0)
+	return FALSE;
+
 unitx = x2unit((gint) (xx - before[0]));
 unity = y2unit((gint) (yy - before[1]));
 cx = unit2x(_center.unitx);
@@ -1535,17 +1538,17 @@ if (_next_way && _next_way->point) {
 	gtk_compass_set_way_heading(mapp.tab_compass, TRUE, wc);
 	wdist=route_get_distance_to(_next_way->point) * UNITS_CONVERT[_units];
 	g_snprintf(buffer, sizeof(buffer), "W: %.02f %s", wdist, UNITS_TEXT[_units]);
-	g_snprintf(buffer2, sizeof(buffer2), "%0.02f", wc<0 ? 360+wc : wc);
+	g_snprintf(buffer2, sizeof(buffer2), "(%3.0f°)", wc<0 ? 360+wc : wc);
 } else {
 	gtk_compass_set_way_heading(mapp.tab_compass, FALSE, 0);
 	if (_dest.valid && !_next_way) {
 		g_snprintf(buffer, sizeof(buffer), "D: %.02f %s", cdist, UNITS_TEXT[_units]);
-		g_snprintf(buffer2, sizeof(buffer2), "%0.02f", dh<0 ? 360+dh : dh);
+		g_snprintf(buffer2, sizeof(buffer2), "(%3.0f°)", dh<0 ? 360+dh : dh);
 	}
 }
 gtk_compass_set_dest_heading(mapp.tab_compass, _dest.valid, (gfloat)dh);
 gtk_label_set_label(GTK_LABEL(mapp.ib.distance), buffer);
-gtk_label_set_label(GTK_LABEL(mapp.ib.direction), buffer);
+gtk_label_set_label(GTK_LABEL(mapp.ib.direction), buffer2);
 }
 
 static gboolean
@@ -1717,17 +1720,19 @@ if (hildon_helper_event_button_is_finger(event)) {
 
 switch (event->button) {
 case 1:
-	if (event->type==GDK_2BUTTON_PRESS) {
+	if (event->type==GDK_2BUTTON_PRESS && map_dragged==0) {
 		gdouble lat, lon;
 		guint ux, uy;
 
 		ux=x2unit((gint) (event->x + 0.5));
 		uy=y2unit((gint) (event->y + 0.5));			
 
-		unit2latlon(ux, uy, lat, lon);
+		g_debug("DBLCLICK");
+
 		if (_gps->data.fix==FIX_NOFIX) {
 			gdouble h;
 
+			unit2latlon(ux, uy, lat, lon);
 			h=calculate_course(_gps->data.lat, _gps->data.lon, lat, lon);
 			_gps->data.heading=(h<0) ? 360+h : h;
 			_gps->data.unitx=ux;
@@ -1741,7 +1746,7 @@ case 1:
 			/* route_update_nears(FALSE); */
 		}
 		/* Fake drag so we don't popup POIs when doubleclicking */
-		map_dragged=666;
+		map_dragged=1;
 		map_center_unit(ux, uy);
 		map_drag_stop(event->x, event->y);
 		map_update_location_from_center_idle();
@@ -1793,7 +1798,7 @@ case 1:
 	ux=x2unit(_cmenu_position_x);
 	uy=y2unit(_cmenu_position_y);
 
-	if (map_dragged<=16) {
+	if (map_dragged==0) {
 		if (map_poi_find_at_map_xy(_cmenu_position_x, _cmenu_position_y, 32, &map_poi_id)==TRUE)
 			map_show_poi_menu(map_poi_id);
 	} else {
