@@ -10,6 +10,7 @@
 
 #include "ui-common.h"
 #include "hildon-mapper.h"
+#include "settings.h"
 
 #ifndef _MAPPER_H
 #define _MAPPER_H
@@ -27,6 +28,7 @@ struct _MapperApp {
 	osso_context_t *osso;
 #endif
 	MapperUi *ui;
+	MapperSettings *s;
 };
 
 MapperApp mapper_app;
