@@ -384,6 +384,8 @@ static gboolean db_insert_node(node *n);
 static guint32 osm_find_way_place(way *w, node_type_t nt);
 static guint32 db_find_nearest_place(node_type_t type, gdouble lat, gdouble lon);
 
+gboolean osm_db_create(sqlite3 *db);
+
 /****************************************************/
 /* Functions */
 /****************************************************/
@@ -837,7 +839,7 @@ if (wmn) {
 	sqlite3_bind_double(sql.insert_way_data, 8, wmn->lat);
 	sqlite3_bind_double(sql.insert_way_data, 9, wmn->lon);
 } else {
-	g_debug("Way [%d] has no nodes");
+	g_debug("Way [%d] has no nodes", w->id);
 }
 
 if (w->data && w->data->isin_p==0 && wmn) {
@@ -1851,6 +1853,7 @@ b=BZ2_bzReadOpen(&bzerror, f, 0, 0, NULL, 0);
 if (bzerror != BZ_OK) {
 	g_printf("BZ2_bzReadOpen failed\n");
 	BZ2_bzReadClose(&bzerror, b);
+	fclose(f);
 	return FALSE;
 }
 
