@@ -735,6 +735,27 @@ static void
 poi_info_url_requested_cb(GtkHTML *html, const char *url, GtkHTMLStream *stream)
 {
 g_debug("URLReq: %s\n", url);
+int fd;
+
+if (url && !strncmp (url, "file://", 7)) {
+	url+=7;
+	fd=open (url, O_RDONLY);
+
+	if (fd!=-1) {
+		gchar *buf;
+		size_t size;
+
+		buf=g_malloc(8192);
+		while ((size=read(fd, buf, 8192)) > 0) {
+			gtk_html_stream_write(stream, buf, size);
+		}
+		gtk_html_stream_close(stream, size == -1 ? GTK_HTML_STREAM_ERROR : GTK_HTML_STREAM_OK);
+		close(fd);
+		g_free(buf);
+		return;
+	}
+}
+
 gtk_html_stream_close(stream, GTK_HTML_STREAM_ERROR);
 }
 
@@ -763,6 +784,8 @@ GtkWidget *sw;
 poi_info *p;
 GtkHTMLStream *s;
 gint ls;
+gchar buf[32];
+const gchar *iname;
 
 p=poi_get_by_id(poi_id);
 if (!p) {
@@ -791,43 +814,51 @@ g_signal_connect(G_OBJECT(info), "title_changed", G_CALLBACK(poi_info_title_cb),
 
 s=gtk_html_begin(GTK_HTML(info));
 ls=strlen(p->label);
+distance_str(buf, sizeof(buf), _gps->data.lat, _gps->data.lon, p->lat, p->lon, _units);
 
 /* XXX: Format lat/lon according to settings */
 
 WRITE_HTML("<html><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\">");
-WRITE_HTML("<head><title>POI - %s</title></head><body><h3>%s</h3><i>%s</i></b><br/><table>" \
-	"<tr><th align=\"left\">Location:</th><td>%.5f, %.5f</td></tr>",
+WRITE_HTML("<head><title>POI - %s</title></head><body><h3>%s</h3><p><i>%s</i><p>", 
 	ls>0 ? p->label : _("(Unknown)"), 
-	ls>0 ? p->label : _("(Unknown)"), p->cat_label, 
-	p->lat, p->lon);
+	ls>0 ? p->label : _("(Unknown)"), p->cat_label);
+
+iname=poi_get_icon_from_type(p->cat_id);
+if (iname) {
+	gchar buf[128];
+
+	poi_get_icon_path(buf, sizeof(buf), TRUE, iname);
+	WRITE_HTML("<img src=\"file://%s\" width=\32\" height=\"32\" align=\"right\">", buf);
+}
+
+WRITE_HTML("<table width='100%' border='0'>");
+WRITE_HTML("<tr><th align=\"left\">Location:</th><td>%.5f, %.5f</td></tr>", p->lat, p->lon);
+WRITE_HTML("<tr><th align=\"left\">Distance:</th><td>%s</td></tr>", buf);
 
 if (p->postal_code)
 	WRITE_HTML("<tr><th align=\"left\">Postal Code:</th><td>%s</td></tr>", p->postal_code);
 if (p->url)
 	WRITE_HTML("<tr><th align=\"left\">Link:</th><td><a href=\"%s\">Web site</a></td></tr>", p->url);
 if (p->desc)
-	WRITE_HTML("<tr><th align=\"left\" colspan=\"2\">Description:</th><td colspan=\"2\">%s</td></tr>", p->desc);
-if (p->osm_id>0)
-	WRITE_HTML("<tr><th align=\"left\">OSM:</th><td><a href=\"http://www.openstreetmap.org/browse/node/%u\">View/Edit on OpenStreetMap.org</a></td></tr>", p->osm_id);
+	WRITE_HTML("<tr><th align=\"left\" colspan=\"2\">Description:</th></tr><tr><td colspan=\"2\">%s</td></tr>", p->desc);
 if (ls>0) {
 	gchar *elabel;
 
 	elabel=gnome_vfs_escape_string(p->label);
-	WRITE_HTML("<tr><th>Search on:</th><td><ul>");
+	WRITE_HTML("<tr><th valign='top' align='left'>Search on:</th><td><ul>");
 	WRITE_HTML("<li><a href=\"http://www.google.com/search?q=%s\">Google</a></li>", elabel);
 	WRITE_HTML("<li><a href=\"http://en.wikipedia.org/wiki/Special:Search?search=%s\">Wikipedia</a></li>", elabel);
 	WRITE_HTML("</ul></td></tr>");
 	g_free(elabel);
 }
 
+if (p->osm_id>0)
+	WRITE_HTML("<tr><th align=\"left\">OSM:</th><td><a href=\"http://www.openstreetmap.org/browse/node/%u\">View/Edit on OpenStreetMap.org</a></td></tr>", p->osm_id);
+
 WRITE_HTML("</table><br/>");
 
-# if 0
-if (p->image)
-	WRITE_HTML("<img src=\"%s\">", p->image);
-#endif
-
 WRITE_HTML("</body></html>");
+
 gtk_html_end(GTK_HTML(info), s, GTK_HTML_STREAM_OK);
 
 poi_free(p);
@@ -1068,10 +1099,10 @@ GtkWidget *buttons[POI_QUICK_BUTTONS];
 GtkWidget *otherbtn;
 guint x, y;
 
-vbox=gtk_vbox_new(FALSE, 6);
+vbox=gtk_vbox_new(FALSE, 0);
 table=gtk_table_new(QPBS_Y, QPBS_X, TRUE);
-gtk_table_set_col_spacings(GTK_TABLE(table), 6);
-gtk_table_set_row_spacings(GTK_TABLE(table), 6);
+gtk_table_set_col_spacings(GTK_TABLE(table), 0);
+gtk_table_set_row_spacings(GTK_TABLE(table), 0);
 
 for (y=0;y<QPBS_Y;y++) {
 	for (x=0;x<QPBS_X;x++) {
@@ -1079,7 +1110,7 @@ for (y=0;y<QPBS_Y;y++) {
 
 		buttons[p]=gtk_button_new_with_label(quick_poi_categories[p].name);
 		poi_button_set_icon(buttons[p], quick_poi_categories[p].type);
-		gtk_table_attach(GTK_TABLE(table), buttons[p], x, x+1, y, y+1, GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL, 6, 6);
+		gtk_table_attach(GTK_TABLE(table), buttons[p], x, x+1, y, y+1, GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
 		g_object_set_data(G_OBJECT(buttons[p]), "pid", GINT_TO_POINTER(quick_poi_categories[p].type));
 		g_signal_connect(G_OBJECT(buttons[p]), "clicked", G_CALLBACK(poi_quick_button_cb), qpdata);
 	}
@@ -1090,11 +1121,14 @@ gtk_box_pack_start(GTK_BOX(vbox), table, TRUE, TRUE, 0);
 /* Other POI button */
 otherbtn=gtk_button_new_with_label("Other");
 poi_button_set_icon(otherbtn, NODE_AMENITY_GENERIC);
-gtk_box_pack_start(GTK_BOX(vbox), otherbtn, TRUE, FALSE, 6);
+#if GTK_CHECK_VERSION(2,10,0)
+gtk_button_set_image_position(GTK_BUTTON(otherbtn), GTK_POS_LEFT);
+#endif
+gtk_box_pack_start(GTK_BOX(vbox), otherbtn, FALSE, FALSE, 0);
 g_object_set_data(G_OBJECT(otherbtn), "pid", GINT_TO_POINTER(NODE_AMENITY_GENERIC));
 g_signal_connect(G_OBJECT(otherbtn), "clicked", G_CALLBACK(poi_quick_button_cb), qpdata);
 
-gtk_box_pack_start(GTK_BOX(vbox), qpdata->label = gtk_entry_new(), TRUE, FALSE, 0);
+gtk_box_pack_start(GTK_BOX(vbox), qpdata->label=gtk_entry_new(), TRUE, FALSE, 0);
 
 return vbox;
 }
