@@ -947,6 +947,12 @@ if (SQLITE_OK == sqlite3_bind_double(poisql.select_nearest_poi, 1, lat)
 return NULL;
 }
 
+gint
+poi_get_icon_path(gchar *buffer, size_t size, gboolean big, const gchar *icon)
+{
+return g_snprintf(buffer, size, "%s/%s.%s/%s.png", theme_base, theme, (big==TRUE) ? "big" : "small", icon);
+}
+
 GdkPixbuf *
 poi_get_icon(const gchar *icon, gboolean big)
 {
@@ -968,7 +974,7 @@ s=image_cache_get(poi_ic, key);
 if (s)
 	return s;
 
-g_snprintf(buffer, sizeof(buffer), "%s/%s.%s/%s.png", theme_base, theme, (big==TRUE) ? "big" : "small", icon);
+poi_get_icon_path(buffer, sizeof(buffer), big, icon);
 s=gdk_pixbuf_new_from_file(buffer, NULL);
 if (s)
 	image_cache_put(poi_ic, g_strdup(key), s, NULL);
