@@ -159,6 +159,9 @@ _track->tail->altitude=gps->altitude;
 _track->maxspeed=gps->maxspeed;
 _track->points++;
 
+if (G_UNLIKELY(_track->points==1))
+	path_insert_mark_text(_track, g_strdup("Start"));
+
 /* Keep the display on if we are moving. */
 keep_display_on(&mapper_app);
 return TRUE;
@@ -271,7 +274,8 @@ tmd->txt_desc=gtk_text_view_new();
 gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(tmd->txt_desc), GTK_WRAP_WORD);
 
 gtk_container_add(GTK_CONTAINER(txt_scroll), tmd->txt_desc);
-gtk_widget_set_size_request(GTK_WIDGET(txt_scroll), 640, 200);
+
+gtk_widget_set_size_request(GTK_WIDGET(tmd->dialog), 640, 200);
 
 return tmd;
 }
