@@ -188,6 +188,12 @@ gtk_window_present(GTK_WINDOW(mapp.mainwindow));
 return FALSE;
 }
 
+static void
+mapper_map_context_menu_items_visibility_cb(GtkWidget *menu, gpointer data)
+{
+map_menu_check_context();
+}
+
 static GtkMenu *
 menu_init_cmenu(void)
 {
@@ -197,7 +203,13 @@ GtkWidget *submenu;
 GtkWidget *menu_item;
 
 /* Setup the context menu. */
+#ifdef WITH_HILDON_2_2
+menu=GTK_MENU(hildon_gtk_menu_new());
+#else
 menu=GTK_MENU(gtk_menu_new());
+#endif
+
+g_signal_connect(G_OBJECT (menu), "show", G_CALLBACK(mapper_map_context_menu_items_visibility_cb), NULL);
 
 /* Setup the map context menu. */
 gtk_menu_append(menu, menu_item	= gtk_menu_item_new_with_label(_("Location")));
@@ -220,8 +232,9 @@ gtk_menu_append(submenu, _cmenu_loc_set_home = gtk_menu_item_new_with_label(_("S
 gtk_menu_append(submenu, _cmenu_loc_set_destination = gtk_menu_item_new_with_label(_("Set as Destination")));
 
 /* Setup the waypoint context menu. */
-gtk_menu_append(menu, menu_item = gtk_menu_item_new_with_label(_("Waypoint")));
-gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu_item), submenu = gtk_menu_new());
+_cmenu_way=gtk_menu_item_new_with_label(_("Waypoint"));
+gtk_menu_append(menu, _cmenu_way);
+gtk_menu_item_set_submenu(GTK_MENU_ITEM(_cmenu_way), submenu = gtk_menu_new());
 
 gtk_menu_append(submenu, _cmenu_way_show_latlon_item = gtk_menu_item_new_with_label(_("Show Lat/Lon")));
 gtk_menu_append(submenu, _cmenu_way_show_desc_item = gtk_menu_item_new_with_label(_("Show Description")));
@@ -420,6 +433,49 @@ gtk_button_set_focus_on_click(GTK_BUTTON(b), FALSE);
 return b;
 }
 
+void
+mapper_info_banner_clear_waypoint_direction(void)
+{
+gtk_image_clear(mapp.ib.op);
+}
+
+void
+mapper_info_banner_set_waypoint_direction(WayPoint *wpt)
+{
+gchar *icon;
+GdkPixbuf *p=NULL;
+
+switch (wpt->t) {
+	case WPT_TURN_LEFT:
+		icon="waypoint/route/left";
+	break;	
+	case WPT_TURN_S_LEFT:
+		icon="waypoint/route/left/soft";
+	break;	
+	case WPT_TURN_H_LEFT:
+		icon="waypoint/route/left/hard";
+	break;	
+	case WPT_TURN_RIGHT:
+		icon="waypoint/route/right";
+	break;
+	case WPT_TURN_S_RIGHT:
+		icon="waypoint/route/right/soft";
+	break;
+	case WPT_TURN_H_RIGHT:
+		icon="waypoint/route/right/hard";
+	break;
+	case WPT_U_TURN:
+		icon="waypoint/route/left/uturn";
+	break;
+	case WPT_CONTINUE:
+	default:
+		icon="waypoint/route/straight";
+	break;
+}
+p=poi_get_icon(icon, TRUE);
+gtk_image_set_from_pixbuf(mapp.ib.op, p);
+}
+
 static GtkWidget *
 mapper_info_banner(void)
 {
@@ -431,8 +487,8 @@ mapp.ib.location_intref=gtk_label_new("");
 mapp.ib.location_name=gtk_label_new("");
 mapp.ib.speed=gtk_label_new("");
 mapp.ib.distance=gtk_label_new("");
+mapp.ib.direction=gtk_label_new("");
 mapp.ib.time=gtk_label_new("--:--");
-
 mapp.ib.op=gtk_image_new();
 mapp.ib.ope=gtk_event_box_new();
 gtk_container_add(GTK_CONTAINER(mapp.ib.ope), mapp.ib.op);
@@ -441,14 +497,14 @@ vbox=gtk_vbox_new(FALSE, 1);
 
 gtk_box_pack_start(GTK_BOX(mapp.ib.container), mapp.ib.ope, FALSE, FALSE, 0);
 gtk_box_pack_start(GTK_BOX(mapp.ib.container), vbox, TRUE, TRUE, 0);
+gtk_box_pack_end(GTK_BOX(mapp.ib.container), mapp.ib.speed, TRUE, TRUE, 0);
 
-#if 0
 gtk_misc_set_alignment(GTK_MISC(mapp.ib.location_intref), 0.f, 0.5f);
 gtk_misc_set_alignment(GTK_MISC(mapp.ib.location_ref), 0.f, 0.5f);
 gtk_misc_set_alignment(GTK_MISC(mapp.ib.location_name), 0.f, 0.5f);
+
+gtk_misc_set_alignment(GTK_MISC(mapp.ib.distance), 0.f, 0.5f);
 gtk_misc_set_alignment(GTK_MISC(mapp.ib.speed), 1.f, 0.5f);
-gtk_misc_set_alignment(GTK_MISC(mapp.ib.distance), 1.f, 0.5f);
-#endif
 
 lhbox=gtk_hbox_new(FALSE, 1);
 gtk_box_pack_start(GTK_BOX(lhbox), mapp.ib.location_intref, FALSE, FALSE, 0);
@@ -456,8 +512,8 @@ gtk_box_pack_start(GTK_BOX(lhbox), mapp.ib.location_ref, FALSE, FALSE, 0);
 gtk_box_pack_start(GTK_BOX(lhbox), mapp.ib.location_name, TRUE, TRUE, 0);
 
 dhbox=gtk_hbox_new(FALSE, 1);
-gtk_box_pack_start(GTK_BOX(dhbox), mapp.ib.distance, TRUE, TRUE, 0);
-gtk_box_pack_end(GTK_BOX(dhbox), mapp.ib.speed, TRUE, TRUE, 0);
+gtk_box_pack_start(GTK_BOX(dhbox), mapp.ib.distance, FALSE, TRUE, 0);
+gtk_box_pack_start(GTK_BOX(dhbox), mapp.ib.direction, FALSE, TRUE, 0);
 
 gtk_box_pack_start(GTK_BOX(vbox), lhbox, TRUE, FALSE, 0);
 gtk_box_pack_start(GTK_BOX(vbox), dhbox, TRUE, FALSE, 0);
@@ -738,8 +794,13 @@ gboolean
 gps_info_update(Gps *gps)
 {
 g_return_val_if_fail(gps, FALSE);
-gps_display_data(&gps->data);
-gps_display_data_speed(mapp.ib.speed, gps->data.speed, _speed_excess, "x-large");
+if (gps->io.conn!=RCVR_OFF) {
+	gps_display_data(&gps->data);
+	gps_display_data_speed(mapp.ib.speed, gps->data.speed, _speed_excess, "x-large");
+} else {
+	gps_info_clear();
+	gtk_label_set_label(GTK_LABEL(mapp.ib.speed), "");
+}
 
 return FALSE;
 }
